.. NWB Widgets documentation master file, created by
   sphinx-quickstart on Thu Sep 22 19:23:41 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

NWB Widgets
=======================================
..
  :scale: 100 %
  :align: right

NWB Widgets is a library of widgets for visualization NWB data in a Jupyter notebook (or lab). The widgets allow you to navigate through the hierarchical structure of the NWB file and visualize specific data elements. It is designed to work out-of-the-box with NWB 2.0 files and to be easy to extend.

.. raw:: html

    <div>
        <iframe width="560" height="315" src="https://www.youtube.com/embed/XoWdLNS_wHE" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
    </div>

.. note::

    This packages is in alpha development; as such, we make every effort towards
    a stable environment but bugs may occur. If you discover any issues, please
    let us know through the `GitHub Issues <https://github.com/NeurodataWithoutBorders/nwbwidgets/issues>`_ page.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   contents/installation
   contents/running_on_jupyter
   contents/running_remotely
   contents/developer_guide

.. toctree::
   :maxdepth: 3
   :caption: Neurodata Widgets:

   contents/neurodata_widgets

.. toctree::
   :maxdepth: 2
   :caption: API reference:

   api_reference/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
